@@ -277,7 +277,7 @@ hildon_code_dialog_init                         (HildonCodeDialog *dialog)
     gtk_container_add (GTK_CONTAINER (priv->buttons[3][2]), image1);
     dialog_action_area1 = GTK_DIALOG (dialog)->action_area;
     gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1),
-            GTK_BUTTONBOX_END);
+            GTK_BUTTONBOX_CENTER);
 
     okButton = gtk_dialog_add_button (GTK_DIALOG (dialog) ,DEVICELOCK_OK,
             GTK_RESPONSE_OK);
