@@ -9,7 +9,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
  * as published by the Free Software Foundation; version 2.1 of
- * the License.
+ * the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +25,7 @@
 
 /**
  * SECTION:hildon-color-chooser
- * @short_description: A widget used to select a color from an HSV colorspace
+ * @short_description: A widget used to select a color from an HSV colorspace.
  * @see_also: #HildonColorChooserDialog
  *
  * HildonColorChooser is a widget that displays an HSV colorspace. 
@@ -371,7 +371,6 @@ hildon_color_chooser_size_allocate              (GtkWidget *widget,
     }
 }
 
-
 static void
 hildon_color_chooser_realize                    (GtkWidget *widget)
 {
@@ -771,15 +770,16 @@ init_borders                                    (GtkWidget *w,
  * @color: a color to be set
  *
  * Sets the color selected in the widget.
+ * Will move the crosshair pointer to indicate the passed color.
  */
 void 
-hildon_color_chooser_set_color                  (HildonColorChooser *sel, 
+hildon_color_chooser_set_color                  (HildonColorChooser *chooser, 
                                                  GdkColor *color)
 {
     unsigned short hue, sat, val;
     unsigned long min, max;
     signed long tmp, diff;
-    HildonColorChooserPrivate *priv = HILDON_COLOR_CHOOSER_GET_PRIVATE (sel);
+    HildonColorChooserPrivate *priv = HILDON_COLOR_CHOOSER_GET_PRIVATE (chooser);
 
     g_assert (priv);
 
@@ -815,8 +815,8 @@ hildon_color_chooser_set_color                  (HildonColorChooser *sel,
     priv->currsat = sat;
     priv->currval = val;
 
-    inline_limited_expose (sel);
-    g_signal_emit (sel, color_chooser_signals[COLOR_CHANGED], 0);
+    inline_limited_expose (chooser);
+    g_signal_emit (chooser, color_chooser_signals[COLOR_CHANGED], 0);
 }
 
 inline void
@@ -1244,19 +1244,26 @@ hildon_color_chooser_expose_timer               (gpointer data)
     return FALSE;
 }
 
-/* FIXME Missing documentation */
+/**
+ * hildon_color_chooser_get_color:
+ * @chooser: a #HildonColorChooser
+ * @color: a color structure to fill with the currently selected color
+ *
+ * Retrives the currently selected color in the chooser.
+ *
+ */
 void
-hildon_color_chooser_get_color                  (HildonColorChooser *sel, 
+hildon_color_chooser_get_color                  (HildonColorChooser *chooser, 
                                                  GdkColor *color)
 {
     HildonColorChooserPrivate *priv;
     GdkVisual *system_visual = gdk_visual_get_system ();
     unsigned long rgb[3], rgb2[3];
 
-    g_return_if_fail (HILDON_IS_COLOR_CHOOSER (sel));
+    g_return_if_fail (HILDON_IS_COLOR_CHOOSER (chooser));
     g_return_if_fail (color != NULL);
 
-    priv = HILDON_COLOR_CHOOSER_GET_PRIVATE (sel);
+    priv = HILDON_COLOR_CHOOSER_GET_PRIVATE (chooser);
     g_assert (priv);
 
     inline_h2rgb (priv->currhue, rgb);
@@ -1314,9 +1321,9 @@ hildon_color_chooser_get_property               (GObject *object,
     {
 
         case PROP_COLOR: {
-            GdkColor *color = g_new (GdkColor, 1);
-            hildon_color_chooser_get_color ((HildonColorChooser *) object, color);
-            g_value_take_boxed (value, color);
+            GdkColor color;
+            hildon_color_chooser_get_color ((HildonColorChooser *) object, &color);
+            g_value_set_boxed (value, &color);
             } break;
 
         default:
