@@ -770,6 +770,10 @@ hildon_window_destroy                           (GtkObject *obj)
     HildonWindowPrivate *priv = HILDON_WINDOW_GET_PRIVATE (obj);
     GList *menu_list = NULL;
     GList *menu_node = NULL;
+
+    gtk_widget_hide ((GtkWidget *) self);
+    while (gtk_events_pending ())
+        gtk_main_iteration ();
     
     g_assert (priv != NULL);
 
@@ -832,7 +836,6 @@ hildon_window_destroy                           (GtkObject *obj)
     GTK_OBJECT_CLASS (parent_class)->destroy (obj);
 }
 
-
 static void
 hildon_window_notify                            (GObject *gobject, 
                                                  GParamSpec *param)
